<?php

$LANG = array(

# install.php
'L_INSTALL_TITLE'					=> 'Installazione',
'L_WRONG_PHP_VERSION'				=> 'PluXml ha bisogno di PHP5 o superiore per funzionare.',
'L_SELECT_LANG'						=> 'Selezionare la lingua',
'L_INPUT_CHANGE'					=> 'Cambia',
'L_DEFAULT_CATEGORY_TITLE'			=> 'Voce 1',
'L_DEFAULT_CATEGORY_URL'			=> 'voce-1',
'L_DEFAULT_STATIC_TITLE'			=> 'Statica 1',
'L_DEFAULT_STATIC_URL'				=> 'statica-1',
'L_DEFAULT_ARTICLE_TITLE'			=> 'Primo articolo',
'L_DEFAULT_ARTICLE_URL'				=> 'primo-articolo',
'L_DEFAULT_COMMENT_CONTENT'			=> 'Questo è un primo commento !',
'L_ERR_PLUXML_ALREADY_INSTALLED'	=> 'PluXml è già configurato !',
'L_ERR_MISSING_USER'				=> 'Inserisci il nome del redattore !',
'L_ERR_MISSING_LOGIN'				=> 'Inserisci il nome utente !',
'L_ERR_MISSING_PASSWORD'			=> 'Inserisci una password !',
'L_ERR_PASSWORD_CONFIRMATION'		=> 'Conferma della password non corretta !',
'L_PLUXML_INSTALLATION'				=> 'Installazione di PluXml',
'L_SITE_DESCRIPTION'				=> 'Blog o Cms XML powered !',
'L_VERSION'							=> 'versione',
'L_USERNAME'						=> 'Nome dell\'amministratore',
'L_LOGIN'							=> 'Nome utente dell\'amministrazione',
'L_PASSWORD'						=> 'Password',
'L_PASSWORD_CONFIRMATION'			=> 'Conferma password',
'L_INPUT_INSTALL'					=> 'Installa',
'L_TIMEZONE'						=> 'Fuso orario',
'L_PWD_VERY_WEAK'					=> 'Password molto debole',
'L_PWD_WEAK'						=> 'Password debole',
'L_PWD_GOOD'						=> 'Buona password',
'L_PWD_STRONG'						=> 'Password complessa',
);
?>
